==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebColumnVisibilityChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata } from "./WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangingEventArgsDescription } from "./WebColumnVisibilityChangingEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnVisibilityChangingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnVisibilityChangingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnVisibilityChangingEventArgsDescriptionMetadata.a == null) {
                WebColumnVisibilityChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnVisibilityChangingEventArgsDescriptionMetadata.c(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
            WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnVisibilityChangingEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebColumnVisibilityChangingEventArgsDetail");
        }
        static d(a) {
            WebColumnVisibilityChangingEventArgsDescriptionMetadata.b(a);
            a.ad("WebColumnVisibilityChangingEventArgs", () => new WebColumnVisibilityChangingEventArgsDescription());
            a.ac("WebColumnVisibilityChangingEventArgs", WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.$t = markType(WebColumnVisibilityChangingEventArgsDescriptionMetadata, 'WebColumnVisibilityChangingEventArgsDescriptionMetadata');
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.a = null;
    return WebColumnVisibilityChangingEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebColumnVisibilityChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata } from "./WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangingEventArgsDescription } from "./WebColumnVisibilityChangingEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnVisibilityChangingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnVisibilityChangingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnVisibilityChangingEventArgsDescriptionMetadata.a == null) {
                WebColumnVisibilityChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnVisibilityChangingEventArgsDescriptionMetadata.c(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
            WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnVisibilityChangingEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebColumnVisibilityChangingEventArgsDetail");
        }
        static d(a) {
            WebColumnVisibilityChangingEventArgsDescriptionMetadata.b(a);
            a.ae("WebColumnVisibilityChangingEventArgs", () => new WebColumnVisibilityChangingEventArgsDescription());
            a.ad("WebColumnVisibilityChangingEventArgs", WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.$t = markType(WebColumnVisibilityChangingEventArgsDescriptionMetadata, 'WebColumnVisibilityChangingEventArgsDescriptionMetadata');
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.a = null;
    return WebColumnVisibilityChangingEventArgsDescriptionMetadata;
})();
